==> apache-druid-25.0.0-src.tar.gz: apache-druid-25.0.0-src/processing/src/main/java/org/apache/druid/query/timeseries/TimeseriesResultBuilder.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.query.timeseries;

import org.apache.druid.query.Result;
import org.joda.time.DateTime;

import java.util.HashMap;
import java.util.Map;

/**
 */
public class TimeseriesResultBuilder
{
  private final DateTime timestamp;

  private final Map<String, Object> metricValues = new HashMap<String, Object>();

  public TimeseriesResultBuilder(
      DateTime timestamp
  )
  {
    this.timestamp = timestamp;
  }

  public TimeseriesResultBuilder addMetric(String name, Object value)
  {
    metricValues.put(name, value);
    return this;
  }

  public Result<TimeseriesResultValue> build()
  {
    return new Result<>(
        timestamp,
        new TimeseriesResultValue(metricValues)
    );
  }
}

==> apache-druid-32.0.1-src.tar.gz: apache-druid-32.0.1-src/processing/src/main/java/org/apache/druid/query/timeseries/TimeseriesResultBuilder.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.query.timeseries;

import org.apache.druid.query.Result;
import org.joda.time.DateTime;

import java.util.HashMap;
import java.util.Map;

/**
 */
public class TimeseriesResultBuilder
{
  private final DateTime timestamp;

  private final Map<String, Object> metricValues = new HashMap<>();

  public TimeseriesResultBuilder(
      DateTime timestamp
  )
  {
    this.timestamp = timestamp;
  }

  public TimeseriesResultBuilder addMetric(String name, Object value)
  {
    metricValues.put(name, value);
    return this;
  }

  public Result<TimeseriesResultValue> build()
  {
    return new Result<>(
        timestamp,
        new TimeseriesResultValue(metricValues)
    );
  }
}
